pub struct GatewayTlsBackendClientCertificateRef {
pub group: Option<String>,
pub kind: Option<String>,
pub name: String,
pub namespace: Option<String>,
}Expand description
ClientCertificateRef references an object that contains a client certificate and its associated private key. It can reference standard Kubernetes resources, i.e., Secret, or implementation-specific custom resources.
A ClientCertificateRef is considered invalid if:
-
It refers to a resource that cannot be resolved (e.g., the referenced resource does not exist) or is misconfigured (e.g., a Secret does not contain the keys named
tls.crtandtls.key). In this case, theResolvedRefscondition on the Gateway MUST be set to False with the ReasonInvalidClientCertificateRefand the Message of the Condition MUST indicate why the reference is invalid. -
It refers to a resource in another namespace UNLESS there is a ReferenceGrant in the target namespace that allows the certificate to be attached. If a ReferenceGrant does not allow this reference, the
ResolvedRefscondition on the Gateway MUST be set to False with the ReasonRefNotPermitted.
Implementations MAY choose to perform further validation of the certificate content (e.g., checking expiry or enforcing specific formats). In such cases, an implementation-specific Reason and Message MUST be set.
Support: Core - Reference to a Kubernetes TLS Secret (with the type kubernetes.io/tls).
Support: Implementation-specific - Other resource kinds or Secrets with a
different type (e.g., Opaque).
Fields
group: Option<String>Group is the group of the referent. For example, “gateway.networking.k8s.io”. When unspecified or empty string, core API group is inferred.
kind: Option<String>Kind is kind of the referent. For example “Secret”.
name: StringName is the name of the referent.
namespace: Option<String>Namespace is the namespace of the referenced object. When unspecified, the local namespace is inferred.
Note that when a namespace different than the local namespace is specified, a ReferenceGrant object is required in the referent namespace to allow that namespace’s owner to accept the reference. See the ReferenceGrant documentation for details.
Support: Core